create or replace view StorEdge_RM_AllAssetsQueryHVB as
-- arrays -------------------------------------------
SELECT	
   	1 AS Ordinal,    
   	count(sa.esm_object_path) as Quantity,
	SUM(sa.criticalalarms) as criticalalarms,
	SUM(sa.majoralarms) as majoralarms,
    	SUM(sa.minoralarms) as minoralarms,
	SUM(sa.totalcapacity) as capacity,
	SUM(sa.totalunusedcapacity) as avail_cap,
	'esm.common.assettype.array' as esmNavAssetType
FROM 	RM_StorageArray sa
WHERE ManagementState IN (1,2,3)
UNION ALL
-- clusters -------------------------------------------
SELECT	
	3 AS Ordinal,
	count(cs.esm_object_path) as Quantity,
	SUM(cs.criticalalarms) as criticalalarms,
	SUM(cs.majoralarms) as majoralarms,
	SUM(cs.minoralarms) as minoralarms,
	MAX((select SUM(fs.filesystemsize)
		from cim_filesystems fs,
		hostedfilesystem sc
		where exists (select  esm_object_path 
                     from RM_Cluster cs 
                     where ManagementState IN (1,2,3)
                     and sc.groupcomponent = esm_object_path) and
		sc.partcomponent = fs.esm_object_path
	)) as capacity,
	MAX((select SUM(fs.availablespace)
		from cim_filesystems fs,
		hostedfilesystem sc
		where exists (select  esm_object_path 
                     from RM_Cluster cs 
                     where sc.groupcomponent = esm_object_path 
                      and ManagementState IN (1,2,3)) and
		sc.partcomponent = fs.esm_object_path
	)) as avail_cap,
	'esm.common.assettype.cluster' as esmNavAssetType
FROM 	RM_Cluster cs
WHERE ManagementState IN (1,2,3)
UNION ALL
-- hosts -------------------------------------------
SELECT	
	6 AS Ordinal,
	count(cs.esm_object_path) as Quantity,
	SUM(cs.criticalalarms) as criticalalarms,
	SUM(cs.majoralarms) as majoralarms,
	SUM(cs.minoralarms) as minoralarms,
	MAX((select SUM(fs.filesystemsize)
		from cim_filesystems fs,
		hostedfilesystem sc
		where exists (select esm_object_path 
                     from RM_UnitaryComputerSystem 
                     where  ManagementState IN (1,2,3) 
                       and sc.groupcomponent = esm_object_path) and
		sc.partcomponent = fs.esm_object_path
	)) as capacity,
	MAX((select SUM(fs.availablespace)
		from cim_filesystems fs,
		hostedfilesystem sc
		where exists (select esm_object_path 
                     from RM_UnitaryComputerSystem 
                     where  sc.groupcomponent = esm_object_path 
                       and ManagementState IN (1,2,3)) and
		sc.partcomponent = fs.esm_object_path
	)) as avail_cap,
	'esm.common.assettype.host' as esmNavAssetType
FROM	RM_ComputerSystem cs
WHERE ManagementState IN (1,2,3)
UNION ALL
-- switches --------------------------------
--- -0.000000000000000000009 makes "N/A" showup in the UI ----
SELECT	
	7 AS Ordinal,
	count(ss.esm_object_path) as Quantity,
	SUM(ss.criticalalarms) as criticalalarms,
	SUM(ss.majoralarms) as majoralarms,
	SUM(ss.minoralarms) as minoralarms,
	-0.000000000000000000009 as capacity,
	-0.000000000000000000009 as avail_cap,
	'esm.common.assettype.switch' as esmNavAssetType
FROM	RM_SANSwitch ss
WHERE ManagementState IN (1,2,3)
UNION ALL
-- file systems --------------------------------
SELECT	
	5 AS Ordinal,
	count(fs.esm_object_path) as Quantity,
	SUM(fs.criticalalarms),
	SUM(fs.majoralarms),
	SUM(fs.minoralarms),
	SUM(fs.filesystemsize) as capacity,
	SUM(fs.availablespace) as avail_cap,
	'esm.common.assettype.filesystem' as esmNavAssetType
FROM	cim_filesystems fs,
	HostedFileSystem hfs
WHERE ManagementState IN (1,2)
	AND fs.esm_object_path = hfs.PartComponent (+)
	AND NOT EXISTS (
	   SELECT pcs.antecedent 
	   FROM CIM_ParticipatingCSS pcs, RM_Clusters cl, HostedFileSystem hfs1 
	   WHERE pcs.dependent 	=cl.esm_object_path 
	     AND fs.esm_object_path = hfs1.PartComponent 
	     AND hfs1.GroupComponent =cl.esm_object_path
	     AND hfs.GroupComponent=pcs.antecedent)
UNION ALL
-- volumes --------------------------------
--- -0.000000000000000000009 makes "N/A" showup in the UI ----
SELECT	
	7 AS Ordinal,
	count(se.esm_object_path) as Quantity,
	SUM(se.criticalalarms),
	SUM(se.majoralarms),
	SUM(se.minoralarms),
	SUM(se.totalstorage) as capacity,
	-0.000000000000000000009 as avail_cap,
	'esm.common.assettype.volume' as esmNavAssetType
FROM	RM_StorageVolume se,
  	SystemDevice sd
WHERE se.ManagementState IN (1,2)
	AND se.esm_object_path = sd.PartComponent (+)
	AND NOT EXISTS ( 
	   SELECT pcs.antecedent 
	   FROM CIM_ParticipatingCSS pcs, RM_Clusters cl, SystemDevice sd1 
	   WHERE pcs.dependent 	=cl.esm_object_path 
	     AND se.esm_object_path = sd1.PartComponent 
	     AND sd1.GroupComponent =cl.esm_object_path
	     AND sd.GroupComponent=pcs.antecedent)
UNION ALL
-- disks --------------------------------
SELECT	
	4 AS Ordinal,
	count(mad.esm_object_path) as Quantity,
	SUM(mad.criticalalarms),
	SUM(mad.majoralarms),
	SUM(mad.minoralarms),
	SUM(mad.totalcapacity) as capacity,
	-0.000000000000000000009 as avail_cap,
	'esm.common.assettype.disk' as esmNavAssetType
FROM	RM_DiskDrive mad,
      RM_PathToDisk ptd
WHERE mad.ManagementState IN (1,2)
      AND mad.esm_object_path = ptd.PartComponent
      AND NOT EXISTS (
          SELECT pcs.antecedent 
          FROM CIM_ParticipatingCSS pcs, RM_Clusters cl, RM_PathToDisk ptd1 
          WHERE pcs.dependent 	=cl.esm_object_path 
              AND mad.esm_object_path = ptd1.PartComponent 
              AND ptd1.GroupComponent =cl.esm_object_path
              AND ptd.GroupComponent=pcs.antecedent)
UNION ALL
-- volume groups --------------------------------
SELECT	
	9 AS Ordinal,
	count(dg.esm_object_path) as Quantity,
	SUM(dg.criticalalarms),
	SUM(dg.majoralarms),
	SUM(dg.minoralarms),
	SUM(dg.totalstorage) as capacity,
	SUM(dg.availablestorage) as avail_cap,
	'esm.common.assettype.volumegroup' as esmNavAssetType
FROM	RM_VMDiskGroup dg,
	RM_SystemDiskGroup sdg,
	ComputerSystem cs
WHERE ManagementState IN (1,2)
	AND dg.esm_object_path = sdg.PartComponent
	AND sdg.GroupComponent = cs.esm_object_path (+)
	AND NOT EXISTS (
	     SELECT pcs.antecedent 
	     FROM CIM_ParticipatingCSS pcs, RM_Clusters cl, RM_SystemDiskGroup sdg1 
	     WHERE pcs.dependent 	=cl.esm_object_path 
	         AND dg.esm_object_path = sdg1.PartComponent 
	         AND sdg1.GroupComponent =cl.esm_object_path
	         AND sdg.GroupComponent = pcs.antecedent)
UNION ALL
-- databases --------------------------------
--select count(aps.esm_object_path) as Quantity,
--	SUM(aps.criticalalarms),
--	SUM(aps.majoralarms),
--	SUM(aps.minoralarms),
--	SUM((select sum(dbf.filesize)
--		from rm_databasefile dbf	)) as capacity,
--	SUM((select sum(dbf.availablespace)
--		from rm_databasefile dbf	)) as avail_cap,
--	'esm.common.assettype.dbserver' as esmNavAssetType
--from RM_OracleDatabaseSystem aps
--WHERE ManagementState IN (1,2,3)
--UNION
-- luns --------------------------------
--- -0.000000000000000000009 makes "N/A" showup in the UI ----
SELECT	
	2 AS Ordinal,
	count(lv.esm_object_path) as Quantity,
	SUM(lv.criticalalarms),
	SUM(lv.majoralarms),
	SUM(lv.minoralarms),
	SUM(lv.totalcapacity) as capacity,
	-0.000000000000000000009 as avail_cap,
	'esm.common.assettype.lun' as esmNavAssetType
FROM	RM_LogicalVolume lv
WHERE ManagementState IN (1,2);
