#! /usr/bin/ksh
#
# Copyright 2003 Sun Microsystems, Inc. All Rights Reserved.
#
# @(#)component_lib.ksh	1.3 03/03/18
#

#---------------------------------------
# Define Component Level Variables
#---------------------------------------

# The order of these packages reflect the dependencies between the packages

CL_PACKAGES="SUNWesm-platform SUNWesm-data-common SUNWesm-services SUNWesm-ih SUNWesm-container SUNWesm-ui-common SUNWesm-cr-cli-client SUNWesm-support"
CL_L10N_PACKAGES="SUNWcesm-container SUNWfesm-container SUNWjesm-container SUNWcesm-ui-common SUNWfesm-ui-common SUNWjesm-ui-common"

CL_NAME="Platform"
CL_VERSION=2.x
CL_PKG_PATH=$COMPONENT_DIR/../Packages 

export CL_PACKAGES CL_L10N_PACKAGES CL_PKG_PATH CL_NAME CL_VERSION 

: ${ESM_PLATFORM:=$ESM_BASE/platform}
export ESM_PLATFORM

# Ensure LD_LIBRARY_PATH is setup to include Oracle libraries
#
if [ -n "$ORACLE_HOME" ] ; then
    if [ -n "$LD_LIBRARY_PATH" ] ; then
	LD_LIBRARY_PATH="${LD_LIBRARY_PATH}:$ORACLE_HOME/lib"
    else
	LD_LIBRARY_PATH=$ORACLE_HOME/lib
    fi
    export LD_LIBRARY_PATH
fi

# Temp file used to capture SMICC output
#
SMICC_OUT=$ESM_TMP/smicc.out.$$
/usr/bin/rm -f $SMICC_OUT


# --------------------------------------------------------------------
# addSMICCkey keyname keyvalue
#
# Add (register) a key in the SMICC, ensuring no existing key is
# present prior to the registration.
#
addSMICCkey () {

    if isSMICCkeyregistered "$1" ; then
	removeSMICCkey "$1" ||
	    return 1
    fi

    if /usr/sbin/smreg add -p -e "${1}=$2" > $SMICC_OUT 2>&1 ; then
	/usr/bin/rm -f $SMICC_OUT
	return 0
    fi
    
    el_log 1 "`/usr/bin/cat $SMICC_OUT`"
    el_log 1 "Failure to register the '$1' key with the smcwebserver!"

    return 1
}


# --------------------------------------------------------------------
# isSMICCkeyregistered keyname
#
# Check for the existence of a key in the SMICC.
#
isSMICCkeyregistered () {

    /usr/sbin/smreg list | /usr/bin/egrep -s "${1}="

    # Return the exit status
}


# --------------------------------------------------------------------
# removeSMICCkey keyname
#
# Remove (unregister) a key in the SMICC.
#
removeSMICCkey () {

    isSMICCkeyregistered "$1" || return 0

    if /usr/sbin/smreg remove -p -e "$1" > $SMICC_OUT 2>&1 ; then
	/usr/bin/rm -f $SMICC_OUT
	return 0
    fi
    
    el_log 1 "`/usr/bin/cat $SMICC_OUT`"
    el_log 1 "Failure to unregister the '$1' key with the smcwebserver!"

    return 1
}


# --------------------------------------------------------------------
# Restart the SMICC (Lockhart)
#
restartSMICC () {

    stopSMICC
    sleep 1
    startSMICC

    # Return the last exit status
}


# --------------------------------------------------------------------
# Start the SMICC (Lockhart)
#
startSMICC () {

    if /usr/bin/setpgrp /usr/sbin/smcwebserver start > $SMICC_OUT 2>&1 ; then
	/usr/bin/rm -f $SMICC_OUT
	return 0
    fi
    
    el_log 1 "`/usr/bin/cat $SMICC_OUT`"
    el_log 1 "Failure to start the smcwebserver!"

    return 1
}


# --------------------------------------------------------------------
# Stop the SMICC (Lockhart)
#
stopSMICC () {

    if /usr/sbin/smcwebserver stop > $SMICC_OUT 2>&1 ; then
	/usr/bin/rm -f $SMICC_OUT
	return 0
    fi
    
    el_log 1 "`/usr/bin/cat $SMICC_OUT`"
    el_log 1 "Failure to stop the smcwebserver!"

    return 1
}


#---------------------------------------
# Debugging Functions

cl_debug () {
    el_secho 1 $ESM_LOG n "Component Environment Variables:"
    el_secho 1 $ESM_LOG n "    CL_PACKAGES   |$CL_PACKAGES|"
    el_secho 1 $ESM_LOG n "    CL_NAME       |$CL_NAME|"
    el_secho 1 $ESM_LOG n "    CL_VERSION    |$CL_VERSION|"
    el_secho 1 $ESM_LOG n "    CL_PKG_PATH   |$CL_PKG_PATH|"
    el_secho 1 $ESM_LOG n " "
}

