# Presentation Tier Functions

# Presentation Tier (PT) Definitions
#
PT_APPNAME='com.sun.netstorage.mgmt.ui.framework_1.0'
PT_APPDIR=$ESM_PLATFORM/smicc/frameworkweb
PT_APPCONFIG=$PT_APPDIR/WEB-INF/web.xml
PT_APPWAR=$ESM_PLATFORM/smicc/frameworkweb.war


# --------------------------------------------------------------------
# Post Install Function
#
pt_postinstall () {

    # Create the directory used for expanding the application war file,
    # then expand the war file into that directory.
    #
    # NOTE: Do NOT remove the $PT_APPDIR directory prior to war file
    # explosion since the optionally-installed L10N packages may have
    # already created (at least part of) the directory tree.  See the
    # SUNWcesm-ui-common package prototype file for an example of how
    # a UI L10N package references the $PT_APPDIR directory tree.
    #
    if mkdir -p $PT_APPDIR &&
       cd $PT_APPDIR       &&
       jar xf $PT_APPWAR > /dev/null
    then
	# Modify the application configuration file to
	# set key context parameters with resolved paths.
	# The original file is preserved with a ".orig" suffix.
	#
	mv $PT_APPCONFIG ${PT_APPCONFIG}.orig

	sed -e "s|%%ESM_CONFIG%%|$ESM_CONFIG|g"  \
	    -e "s|%%ESM_DPF_ETC%%|$ESM_CONFIG|g" \
	    ${PT_APPCONFIG}.orig > $PT_APPCONFIG ||
	    el_assert "Failure to update the $PT_APPCONFIG file"

	# Register the UI with the SMICC and restart the SMICC
	# to effect the registration, then configure the SMICC
	# to automatically startup at system boot time.
	#
        el_log 1 "Registering the UI with the smcwebserver..."

        if /usr/sbin/smreg add -a $PT_APPDIR ; then

            el_log 1 "Restarting the smcwebserver..."
	    restartSMICC

	    el_log 1 "Configuring the smcwebserver to startup at system boot time..."

	    /usr/bin/setpgrp /usr/sbin/smcwebserver enable

	    el_log 1 ""  # Log spacer line
        else
            el_assert "Failure to register the UI with the smcwebserver"
        fi
    else
        el_log 1 "[Expanded UI war file reside in: $PT_APPDIR]"
        el_assert "Failure to expand the UI war file ($PT_APPWAR)"
    fi
}


# --------------------------------------------------------------------
# Preremove Function
#
pt_preremove () {

    # Unregister the UI with the SMICC if it is currently registered,
    # then restart it to release all formerly held resources.
    #
    if /usr/sbin/smreg list | egrep -s "$PT_APPNAME" ; then

	el_log 1 "Unregistering the UI with the smcwebserver..."

	if /usr/sbin/smreg remove -a "$PT_APPNAME" ; then
            el_log 1 "Restarting the smcwebserver..."
	    restartSMICC
	else
	    el_log 1 "WARNING: Unable to remove the Capacity Reporter application from the smcwebserver"
	fi
    else
	el_log 1 "[The UI is not currently registered with the smcwebserver]"
    fi

    # Remove the application directory created during pt_postinstall()
    #
    rm -rf $PT_APPDIR
}

